----------------------------------
pirt.gaussfun - Gaussian diffusion
----------------------------------

.. automodule:: pirt.gaussfun

----

.. autofunction:: pirt.gaussiankernel

.. autofunction:: pirt.diffusionkernel

.. autofunction:: pirt.gfilter

.. autofunction:: pirt.gfilter2

.. autofunction:: pirt.diffuse

.. autofunction:: pirt.diffuse2

----

Technically implemented in `pyramid.py`, but very much related to Gaussian
diffusion:

.. autoclass:: pirt.ScaleSpacePyramid
    :members:
